@@ -45,7 +45,6 @@ class Instrument(Resource):
         """ """
         if not self.status:
             message = f"Unable to configure {self} as it has disconnected. "
-            logger.error(message)
             raise ConnectionError(message)
 
         super().configure(**parameters)
@@ -53,8 +52,7 @@ class Instrument(Resource):
     def snapshot(self) -> dict[str, Any]:
         """ """
         if not self.status:
-            message = f"{self} has disconnected, returning a minimal snapshot..."
-            logger.error(message)
+            logger.warning(f"{self} has disconnected, returning a minimal snapshot.")
             return {"id": self.id, "name": self.name}
 
         return super().snapshot()
