@@ -5,8 +5,7 @@ import sys
 
 from loguru import logger
 
-# set logs folder path
-LOGSPATH = Path.cwd() / "logs"
+from labctrl.settings import Settings
 
 logger.remove()  # remove default handlers
 
@@ -17,12 +16,13 @@ logger.level("WARNING", color="<magenta>")
 logger.level("ERROR", color="<red>")
 
 log_record_format = (  # customise log record format
-    "<cyan>[{time:YY-MM-DD HH:mm:ss}]</> " "<lvl>{level: <7} [{module}] - {message}</>"
+    "<cyan>[{time:YY-MM-DD HH:mm:ss}]</> "
+    "<lvl>{level: <7} [{module}-{function}] - {message}</>"
 )
 
 # register log sinks with loguru logger
 logger.add(
-    Path(LOGSPATH) / "log.log",
+    Path(Settings().logspath) / "log.log",
     format=log_record_format,
     rotation="24 hours",  # current log file closed and new one started every 24 hours
     retention="1 week",  # log files created more than a week ago will be removed
